@@ -1,5 +1,5 @@
 import typing
-from typing import Optional
+from typing import Optional, Union
 
 from autocoder_nano.agent.agentic_edit_tools.base_tool_resolver import BaseToolResolver
 from autocoder_nano.agent.agentic_edit_types import ToolResult, AttemptCompletionTool
@@ -7,10 +7,15 @@ from autocoder_nano.actypes import AutoCoderArgs
 
 if typing.TYPE_CHECKING:
     from autocoder_nano.agent.agentic_edit import AgenticEdit
+    from autocoder_nano.agent.agentic_ask import AgenticAsk
+    from autocoder_nano.agent.agentic_cost import AgenticCost
 
 
 class AttemptCompletionToolResolver(BaseToolResolver):
-    def __init__(self, agent: Optional['AgenticEdit'], tool: AttemptCompletionTool, args: AutoCoderArgs):
+    def __init__(
+            self, agent: Optional[Union['AgenticEdit', 'AgenticAsk', 'AgenticCost']],
+            tool: AttemptCompletionTool, args: AutoCoderArgs
+    ):
         super().__init__(agent, tool, args)
         self.tool: AttemptCompletionTool = tool
 
