@@ -6,7 +6,10 @@ import json
 import subprocess
 import time
 import uuid
+from datetime import datetime
 
+from autocoder_nano.utils.file_utils import load_tokenizer
+from autocoder_nano.context import get_context_manager, ContextManagerConfig
 from autocoder_nano.chat import stream_chat_display
 from autocoder_nano.edit import run_edit
 from autocoder_nano.helper import show_help
@@ -14,11 +17,12 @@ from autocoder_nano.project import project_source
 from autocoder_nano.index import (index_export, index_import, index_build,
                                   index_build_and_filter, extract_symbols)
 from autocoder_nano.rules import rules_from_active_files, rules_from_commit_changes, get_rules_context
-from autocoder_nano.agent import run_edit_agentic
+from autocoder_nano.agent import (run_edit_agentic, AgenticEditConversationConfig, run_ask_agentic,
+                                  run_cost_agentic)
 from autocoder_nano.rag import rag_build_cache, rag_retrieval
-from autocoder_nano.core import AutoLLM
-from autocoder_nano.core import prompt, extract_code
+from autocoder_nano.core import prompt, extract_code, AutoLLM
 from autocoder_nano.actypes import *
+from autocoder_nano.editor import run_editor
 from autocoder_nano.utils.completer_utils import CommandCompleter
 from autocoder_nano.version import __version__
 from autocoder_nano.templates import create_actions
@@ -26,9 +30,9 @@ from autocoder_nano.utils.git_utils import (repo_init, commit_changes, revert_ch
                                             get_uncommitted_changes, generate_commit_message)
 from autocoder_nano.utils.sys_utils import default_exclude_dirs, detect_env
 from autocoder_nano.utils.printer_utils import Printer
+from autocoder_nano.utils.config_utils import (get_final_config, convert_yaml_config_to_str, convert_config_value,
+                                               convert_yaml_to_config, get_last_yaml_file, prepare_chat_yaml)
 
-import yaml
-from jinja2 import Template
 from prompt_toolkit import prompt as _toolkit_prompt, PromptSession
 from prompt_toolkit.auto_suggest import AutoSuggestFromHistory
 from prompt_toolkit.formatted_text import FormattedText
@@ -36,11 +40,9 @@ from prompt_toolkit.history import InMemoryHistory
 from prompt_toolkit.key_binding import KeyBindings
 from prompt_toolkit.shortcuts import confirm
 from prompt_toolkit.styles import Style
-# from rich.console import Console
 from rich.live import Live
 from rich.panel import Panel
 from rich.syntax import Syntax
-# from rich.table import Table
 from rich.text import Text
 
 
@@ -55,7 +57,7 @@ base_persist_dir = os.path.join(project_root, ".auto-coder", "plugins", "chat-au
 commands = [
     "/add_files", "/remove_files", "/list_files", "/conf", "/coding", "/chat", "/revert", "/index/query",
     "/index/build", "/exclude_dirs", "/exclude_files", "/help", "/shell", "/exit", "/mode", "/models", "/commit",
-    "/rules", "/auto", "/rag/build", "/rag/query"
+    "/rules", "/auto", "/rag/build", "/rag/query", "/editor", "/long_context_auto", "/context"
 ]
 
 memory = {
@@ -186,8 +188,11 @@ def load_memory():
     global memory
     memory_path = os.path.join(base_persist_dir, "nano-memory.json")
     if os.path.exists(memory_path):
-        with open(memory_path, "r") as f:
-            memory = json.load(f)
+        try:
+            with open(memory_path, "r") as f:
+                memory = json.load(f)
+        except json.JSONDecodeError as e:
+            raise Exception(f"打开配置文件失败, 文件内容不是有效的JSON格式, 错误原因: {str(e)} , 文件位置: {memory_path}")
 
 
 def get_memory():
@@ -212,40 +217,6 @@ completer = CommandCompleter(
 )
 
 
-def get_final_config(query: str, delete_execute_file: bool = False) -> AutoCoderArgs | None:
-    conf = memory.get("conf", {})
-    yaml_config = {
-        "include_file": ["./base/base.yml"],
-        "skip_build_index": conf.get("skip_build_index", "true") == "true",
-        "skip_confirm": conf.get("skip_confirm", "true") == "true",
-        "chat_model": conf.get("chat_model", ""),
-        "code_model": conf.get("code_model", ""),
-        "auto_merge": conf.get("auto_merge", "editblock"),
-        "exclude_files": memory.get("exclude_files", [])
-    }
-    current_files = memory["current_files"]["files"]
-    yaml_config["urls"] = current_files
-    yaml_config["query"] = query
-
-    # 如果 conf 中有设置, 则以 conf 配置为主
-    for key, value in conf.items():
-        converted_value = convert_config_value(key, value)
-        if converted_value is not None:
-            yaml_config[key] = converted_value
-
-    execute_file = os.path.join(project_root, "actions", f"{uuid.uuid4()}.yml")
-    try:
-        yaml_content = convert_yaml_config_to_str(yaml_config=yaml_config)
-        with open(os.path.join(execute_file), "w") as f:  # 保存此次查询的细节
-            f.write(yaml_content)
-        args = convert_yaml_to_config(execute_file)  # 更新到args
-    finally:
-        if delete_execute_file:
-            if os.path.exists(execute_file):
-                os.remove(execute_file)
-    return args
-
-
 def exclude_dirs(dir_names: List[str]):
     new_dirs = dir_names
     existing_dirs = memory.get("exclude_dirs", [])
@@ -312,19 +283,19 @@ def exclude_files(query: str):
 
 
 def index_command(llm):
-    args = get_final_config(query="", delete_execute_file=True)
+    args = get_final_config(project_root, memory, query="", delete_execute_file=True)
     index_build(llm=llm, args=args, sources_codes=project_source(source_llm=llm, args=args))
     return
 
 
 def index_query_command(query: str, llm: AutoLLM):
-    args = get_final_config(query=query, delete_execute_file=True)
+    args = get_final_config(project_root, memory, query=query, delete_execute_file=True)
     index_build_and_filter(llm=llm, args=args, sources_codes=project_source(source_llm=llm, args=args))
     return
 
 
 def rag_build_command(llm: AutoLLM):
-    args = get_final_config(query="", delete_execute_file=True)
+    args = get_final_config(project_root, memory, query="", delete_execute_file=True)
     if not args.rag_url:
         printer.print_text("请通过 /conf 设置 rag_url 参数, 即本地目录", style="red")
         return
@@ -333,7 +304,7 @@ def rag_build_command(llm: AutoLLM):
 
 
 def rag_query_command(query: str, llm: AutoLLM):
-    args = get_final_config(query=query, delete_execute_file=True)
+    args = get_final_config(project_root, memory, query=query, delete_execute_file=True)
     if not args.rag_url:
         printer.print_text("请通过 /conf 设置 rag_url 参数, 即本地目录", style="red")
         return
@@ -346,58 +317,8 @@ def rag_query_command(query: str, llm: AutoLLM):
     return
 
 
-def convert_yaml_config_to_str(yaml_config):
-    yaml_content = yaml.safe_dump(
-        yaml_config,
-        allow_unicode=True,
-        default_flow_style=False,
-        default_style=None,
-    )
-    return yaml_content
-
-
-def convert_yaml_to_config(yaml_file: str | dict | AutoCoderArgs):
-    # global args
-    args = AutoCoderArgs()
-    config = {}
-    if isinstance(yaml_file, str):
-        args.file = yaml_file
-        with open(yaml_file, "r") as f:
-            config = yaml.safe_load(f)
-            config = load_include_files(config, yaml_file)
-    if isinstance(yaml_file, dict):
-        config = yaml_file
-    if isinstance(yaml_file, AutoCoderArgs):
-        config = yaml_file.model_dump()
-    for key, value in config.items():
-        if key != "file":  # 排除 --file 参数本身
-            # key: ENV {{VARIABLE_NAME}}
-            if isinstance(value, str) and value.startswith("ENV"):
-                template = Template(value.removeprefix("ENV").strip())
-                value = template.render(os.environ)
-            setattr(args, key, value)
-    return args
-
-
-def convert_config_value(key, value):
-    field_info = AutoCoderArgs.model_fields.get(key)
-    if field_info:
-        if value.lower() in ["true", "false"]:
-            return value.lower() == "true"
-        elif "int" in str(field_info.annotation):
-            return int(value)
-        elif "float" in str(field_info.annotation):
-            return float(value)
-        else:
-            return value
-    else:
-        printer.print_text(f"无效的配置项: {key}", style="red")
-        return None
-
-
 def print_chat_history(history, max_entries=5):
     recent_history = history[-max_entries:]
-    data_list = []
     for entry in recent_history:
         role = entry["role"]
         content = entry["content"]
@@ -426,7 +347,7 @@ def code_review(query: str) -> str:
 
 
 def chat_command(query: str, llm: AutoLLM):
-    args = get_final_config(query)
+    args = get_final_config(project_root, memory, query)
 
     is_history = query.strip().startswith("/history")
     is_new = "/new" in query
@@ -542,92 +463,6 @@ def init_project(project_type):
     return
 
 
-def get_last_yaml_file(actions_dir: str) -> Optional[str]:
-    action_files = [f for f in os.listdir(actions_dir) if f[:3].isdigit() and "_" in f and f.endswith(".yml")]
-
-    def get_old_seq(name):
-        return int(name.split("_")[0])
-
-    sorted_action_files = sorted(action_files, key=get_old_seq)
-    return sorted_action_files[-1] if sorted_action_files else None
-
-
-def resolve_include_path(base_path, include_path):
-    if include_path.startswith(".") or include_path.startswith(".."):
-        full_base_path = os.path.abspath(base_path)
-        parent_dir = os.path.dirname(full_base_path)
-        return os.path.abspath(os.path.join(parent_dir, include_path))
-    else:
-        return include_path
-
-
-def load_include_files(config, base_path, max_depth=10, current_depth=0):
-    if current_depth >= max_depth:
-        raise ValueError(
-            f"Exceeded maximum include depth of {max_depth},you may have a circular dependency in your include files."
-        )
-    if "include_file" in config:
-        include_files = config["include_file"]
-        if not isinstance(include_files, list):
-            include_files = [include_files]
-
-        for include_file in include_files:
-            abs_include_path = resolve_include_path(base_path, include_file)
-            # printer.print_text(f"正在加载 Include file: {abs_include_path}", style="green")
-            with open(abs_include_path, "r") as f:
-                include_config = yaml.safe_load(f)
-                if not include_config:
-                    printer.print_text(f"Include file {abs_include_path} 为空，跳过处理.", style="green")
-                    continue
-                config.update(
-                    {
-                        **load_include_files(include_config, abs_include_path, max_depth, current_depth + 1),
-                        **config,
-                    }
-                )
-        del config["include_file"]
-    return config
-
-
-def prepare_chat_yaml():
-    # auto_coder_main(["next", "chat_action"]) 准备聊天 yaml 文件
-    actions_dir = os.path.join(project_root, "actions")
-    if not os.path.exists(actions_dir):
-        printer.print_text("当前目录中未找到 actions 目录。请执行初始化 AutoCoder Nano", style="yellow")
-        return
-
-    action_files = [
-        f for f in os.listdir(actions_dir) if f[:3].isdigit() and "_" in f and f.endswith(".yml")
-    ]
-
-    def get_old_seq(name):
-        return name.split("_")[0]
-
-    if not action_files:
-        max_seq = 0
-    else:
-        seqs = [int(get_old_seq(f)) for f in action_files]
-        max_seq = max(seqs)
-
-    new_seq = str(max_seq + 1).zfill(12)
-    prev_files = [f for f in action_files if int(get_old_seq(f)) < int(new_seq)]
-
-    if not prev_files:
-        new_file = os.path.join(actions_dir, f"{new_seq}_chat_action.yml")
-        with open(new_file, "w") as f:
-            pass
-    else:
-        prev_file = sorted(prev_files)[-1]  # 取序号最大的文件
-        with open(os.path.join(actions_dir, prev_file), "r") as f:
-            content = f.read()
-        new_file = os.path.join(actions_dir, f"{new_seq}_chat_action.yml")
-        with open(new_file, "w") as f:
-            f.write(content)
-
-    printer.print_text(f"已成功创建新的 action 文件: {new_file}", style="green")
-    return
-
-
 def get_conversation_history() -> str:
     memory_dir = os.path.join(project_root, ".auto-coder", "memory")
     os.makedirs(memory_dir, exist_ok=True)
@@ -669,8 +504,8 @@ def coding_command(query: str, llm: AutoLLM):
     memory["conversation"].append({"role": "user", "content": query})
     conf = memory.get("conf", {})
 
-    prepare_chat_yaml()  # 复制上一个序号的 yaml 文件, 生成一个新的聊天 yaml 文件
-    latest_yaml_file = get_last_yaml_file(os.path.join(project_root, "actions"))
+    prepare_chat_yaml(project_root)  # 复制上一个序号的 yaml 文件, 生成一个新的聊天 yaml 文件
+    latest_yaml_file = get_last_yaml_file(project_root)
 
     if latest_yaml_file:
         yaml_config = {
@@ -729,7 +564,7 @@ def execute_revert(args: AutoCoderArgs):
 
 
 def revert():
-    last_yaml_file = get_last_yaml_file(os.path.join(project_root, "actions"))
+    last_yaml_file = get_last_yaml_file(project_root)
     if last_yaml_file:
         file_path = os.path.join(project_root, "actions", last_yaml_file)
         args = convert_yaml_to_config(file_path)
@@ -757,9 +592,9 @@ def print_commit_info(commit_result: CommitResult):
 
 def commit_info(query: str, llm: AutoLLM):
     repo_path = project_root
-    prepare_chat_yaml()  # 复制上一个序号的 yaml 文件, 生成一个新的聊天 yaml 文件
+    prepare_chat_yaml(project_root)  # 复制上一个序号的 yaml 文件, 生成一个新的聊天 yaml 文件
 
-    latest_yaml_file = get_last_yaml_file(os.path.join(project_root, "actions"))
+    latest_yaml_file = get_last_yaml_file(project_root)
     execute_file = None
 
     if latest_yaml_file:
@@ -772,7 +607,8 @@ def commit_info(query: str, llm: AutoLLM):
                 "skip_confirm": conf.get("skip_confirm", "true") == "true",
                 "chat_model": conf.get("chat_model", ""),
                 "code_model": conf.get("code_model", ""),
-                "auto_merge": conf.get("auto_merge", "editblock")
+                "auto_merge": conf.get("auto_merge", "editblock"),
+                "context": ""
             }
             for key, value in conf.items():
                 converted_value = convert_config_value(key, value)
@@ -827,23 +663,175 @@ def commit_info(query: str, llm: AutoLLM):
                 os.remove(execute_file)
 
 
-def agentic_command(query: str, llm: AutoLLM):
-    args = get_final_config(query=query.strip(), delete_execute_file=True)
+def printer_conversation_table(_conversation_list):
+    data_list = []
+    for i in _conversation_list:
+        data_list.append([
+            i["conversation_id"], f"{i['description'][:20]} ......",
+            datetime.fromtimestamp(i["updated_at"]).strftime("%Y-%m-%d %H:%M"),
+            len(i["messages"])
+        ])
+    printer.print_table_compact(
+        title="历史会话列表",
+        headers=["会话ID", "会话描述", "会话更新时间", "会话消息数量"],
+        data=data_list
+    )
 
-    # sources = SourceCodeList([])
-    # agentic_editor = AgenticEdit(
-    #     args=args, llm=llm, files=sources, history_conversation=[]
-    # )
-    #
-    # query = query.strip()
-    # request = AgenticEditRequest(user_input=query)
-    #
-    # agentic_editor.run_in_terminal(request)
-    run_edit_agentic(llm=llm, args=args)
+
+def auto_command(query: str, llm: AutoLLM):
+    # args = get_final_config(project_root, memory, query=query.strip(), delete_execute_file=True)
+    conversation_config = AgenticEditConversationConfig()
+    # 获取上下文管理器实例
+    cmc = ContextManagerConfig()
+    cmc.storage_path = os.path.join(project_root, ".auto-coder", "context")
+    gcm = get_context_manager(config=cmc)
+
+    def _printer_resume_conversation(_conversation_id):
+        printer.print_panel(
+            Text(f"Agent 恢复对话[{_conversation_id}]", style="green"),
+            title="Agent Session Status",
+            center=True
+        )
+
+    def _resume_conversation(_query):
+        _conv_id = gcm.get_current_conversation_id()
+        if not _conv_id:
+            printer.print_text(f"未获取到当前会话ID, 请手动进行选择", style="yellow")
+            _convs = gcm.list_conversations(limit=10)
+            if _convs:
+                printer_conversation_table(_convs)
+                _conv_id = input(f"  以上为最近10个会话列表, 请选择您想要恢复对话的ID: ").strip().lower()
+                conversation_config.action = "resume"
+                conversation_config.query = query.strip()
+                conversation_config.conversation_id = _conv_id
+                _printer_resume_conversation(_conv_id)
+            else:
+                printer.print_text(f"未获取到历史会话, 默认创建新会话开始 Agent", style="yellow")
+                conversation_config.action = "new"
+                conversation_config.query = query.strip()
+                conversation_config.conversation_id = None
+                printer.print_panel(
+                    Text("Agent 新会话已开始.", style="green"),
+                    title="Agent Session Status",
+                    center=True
+                )
+        else:
+            # 这里可能需要判断一下会话id是否真实存在
+            conversation_config.action = "resume"
+            conversation_config.query = query.strip()
+            conversation_config.conversation_id = _conv_id
+            _printer_resume_conversation(_conv_id)
+
+    if "/new" in query:
+        query = query.replace("/new", "", 1).strip()
+        conversation_config.action = "new"
+        conversation_config.query = query
+        conversation_config.conversation_id = None
+        printer.print_panel(
+            Text("Agent 新会话已开始.", style="green"),
+            title="Agent Session Status",
+            center=True
+        )
+    elif "/resume" in query:
+        query = query.replace("/resume", "", 1).strip()
+        convs = gcm.list_conversations(limit=10)
+        if convs:
+            printer_conversation_table(convs)
+            conv_id = input(f" 以上为最近10个会话列表, 请选择您想要恢复对话的ID: ").strip().lower()
+            conversation_config.action = "resume"
+            conversation_config.query = query.strip()
+            conversation_config.conversation_id = conv_id
+            _printer_resume_conversation(conv_id)
+        else:
+            raise Exception("未获取到历史会话, 请直接使用 /auto 或者 /auto /new")
+        # _resume_conversation(query)
+    else:
+        _resume_conversation(query)
+
+    args = get_final_config(project_root, memory, query=query, delete_execute_file=True)
+    cost = run_cost_agentic(llm=llm, args=args, conversation_config=conversation_config)
+
+    # 使用历史对话
+    conversation_config.action = "resume"
+    conversation_config.conversation_id = gcm.get_current_conversation_id()
+
+    cost_dict = json.loads(cost)
+    if cost_dict and isinstance(cost_dict, dict):
+        printer.print_key_value(items=cost_dict)
+        if cost_dict["need_research"]:
+            pass
+        if cost_dict["need_ask"]:
+            run_ask_agentic(llm=llm, args=args, conversation_config=conversation_config)
+
+        run_edit_agentic(llm=llm, args=args, conversation_config=conversation_config)
+    else:
+        run_edit_agentic(llm=llm, args=args, conversation_config=conversation_config)
+    # if args.enable_agentic_ask:
+    #     run_ask_agentic(llm=llm, args=args, conversation_config=conversation_config)
+    #     ask_file = os.path.join(args.source_dir, ".auto-coder", "ask.txt")
+    #     with open(os.path.join(ask_file), "r") as f:
+    #         ask_content = f.read()
+    #     if args.only_ask:
+    #         printer.print_markdown(text=ask_content, panel=True)
+    #     else:
+    #         conversation_config.action = "resume"
+    #         conversation_config.query = ask_content
+    #         conversation_config.conversation_id = gcm.get_current_conversation_id()
+    #         run_edit_agentic(llm=llm, args=args, conversation_config=conversation_config)
+    # else:
+    #     run_edit_agentic(llm=llm, args=args, conversation_config=conversation_config)
+
+
+def long_context_auto_command(llm: AutoLLM):
+    import tempfile
+    initial_content = f"请输入你的需求: \n"
+    # 创建临时文件
+    with tempfile.NamedTemporaryFile(mode='w+', delete=True, suffix='.txt') as tmpfile:
+        tmpfile.write(initial_content)
+        tmpfile.flush()
+        temp_path = tmpfile.name
+        query = run_editor(temp_path)
+
+    args = get_final_config(project_root, memory, query=query.strip(), delete_execute_file=True)
+    conversation_config = AgenticEditConversationConfig(
+        action="new",
+        query=query.strip()
+    )
+    run_edit_agentic(llm=llm, args=args, conversation_config=conversation_config)
+
+
+def context_command(context_args):
+    # 获取上下文管理器实例
+    cmc = ContextManagerConfig()
+    cmc.storage_path = os.path.join(project_root, ".auto-coder", "context")
+    gcm = get_context_manager(config=cmc)
+
+    if context_args[0] == "/list":
+        printer_conversation_table(gcm.list_conversations(limit=10))
+
+    if context_args[0] == "/remove":
+        printer_conversation_table(gcm.list_conversations(limit=10))
+        delete_conv_id = input(f" 以上为最近10个会话列表, 请选择您想要删除的对话ID: ").strip().lower()
+        delete_conv = gcm.get_conversation(delete_conv_id)
+        if delete_conv is None:
+            printer.print_text(f"该会话不存在 {delete_conv_id}", style="yellow")
+        if isinstance(delete_conv, dict):
+            try:
+                if gcm.delete_conversation(delete_conv_id):
+                    printer.print_text(f"删除会话 {delete_conv_id} 成功, 会话条数 {len(delete_conv['messages'])}", style="green")
+                else:
+                    printer.print_text(f"删除会话 {delete_conv_id} 失败, 会话可能不存在", style="red")
+            except Exception as e:
+                printer.print_text(f"{e}", style="red")
+
+
+def editor_command(file_path: str):
+    abs_input_path = os.path.abspath(os.path.join(project_root, file_path)) if not os.path.isabs(file_path) else file_path
+    run_editor(abs_input_path)
 
 
 @prompt()
-def _generate_shell_script(user_input: str) -> str:
+def _generate_shell_script(user_input: str):
     """
     环境信息如下:
 
@@ -879,7 +867,7 @@ def _generate_shell_script(user_input: str) -> str:
 
 
 def generate_shell_command(input_text: str, llm: AutoLLM) -> str | None:
-    args = get_final_config(query=input_text, delete_execute_file=True)
+    args = get_final_config(project_root, memory, query=input_text, delete_execute_file=True)
 
     try:
         printer.print_panel(
@@ -948,85 +936,12 @@ def execute_shell_command(command: str):
 
 
 def parse_args(input_args: Optional[List[str]] = None):
-    parser = argparse.ArgumentParser(description="使用AI编程")
+    parser = argparse.ArgumentParser(description="Auto-Coder Nano")
 
-    parser.add_argument("--debug", action="store_true",
-                        help="Enable debug mode")
-    parser.add_argument(
-        "--quick",
-        action="store_true",
-        help="Enter the auto-coder.chat without initializing the system",
-    )
-
-    parser.add_argument("--request_id", default="", help="Request ID")
-    parser.add_argument("--source_dir", required=False, help="项目源代码目录路径")
-    parser.add_argument("--git_url", help="用于克隆源代码的Git仓库URL")
-    parser.add_argument("--target_file", required=False, help="生成的源代码的输出文件路径")
-    parser.add_argument("--query", help="用户查询或处理源代码的指令")
-    parser.add_argument("--template", default="common", help="生成源代码使用的模板。默认为'common'")
-    parser.add_argument("--project_type", default="py",
-                        help="项目类型。当前可选值:py。默认为'py'")
-    parser.add_argument("--execute", action="store_true", help="模型是否生成代码")
-    parser.add_argument("--model", default="", help="使用的模型名称。默认为空")
-    parser.add_argument(
-        "--model_max_input_length",
-        type=int,
-        default=6000,
-        help="模型的最大输入长度。默认为6000。",
-    )
-    parser.add_argument(
-        "--index_filter_level", type=int, default=0,
-        help="索引过滤级别,0:仅过滤query 中提到的文件名，1. 过滤query 中提到的文件名以及可能会隐含会使用的文件 2. 从0,1 中获得的文件，再寻找这些文件相关的文件。"
-    )
-    parser.add_argument(
-        "--index_filter_workers", type=int, default=1, help="用于通过索引过滤文件的工作线程数"
-    )
-    parser.add_argument(
-        "--index_filter_file_num",
-        type=int,
-        default=-1,
-        help="过滤后的最大文件数。默认为-1,即全部",
-    )
-    parser.add_argument(
-        "--index_build_workers", type=int, default=1, help="用于构建索引的工作线程数"
-    )
-    parser.add_argument("--file", default=None, required=False, help="YAML配置文件路径")
-    parser.add_argument(
-        "--anti_quota_limit", type=int, default=1, help="每次API请求后等待的秒数。默认为1秒"
-    )
-    parser.add_argument(
-        "--skip_build_index", action="store_false", help="是否跳过构建源代码索引。默认为False"
-    )
-    parser.add_argument(
-        "--skip_filter_index", action="store_true", help="是否跳过使用索引过滤文件。默认为False"
-    )
-    parser.add_argument(
-        "--human_as_model", action="store_true", help="是否使用人工作为模型(功能开发中)。默认为False"
-    )
-    parser.add_argument(
-        "--human_model_num", type=int, default=1, help="使用的人工模型数量。默认为1"
-    )
-    parser.add_argument("--urls", default="", help="要爬取并提取文本的URL,多个URL以逗号分隔")
-    parser.add_argument(
-        "--auto_merge", nargs="?", const=True, default=False,
-        help="是否自动将生成的代码合并到现有文件中。默认为False。"
-    )
-    parser.add_argument(
-        "--editblock_similarity", type=float, default=0.9,
-        help="合并编辑块时TextSimilarity的相似度阈值。默认为0.9",
-    )
-    parser.add_argument(
-        "--enable_multi_round_generate", action="store_true",
-        help="是否开启多轮对话生成。默认为False",
-    )
-    parser.add_argument(
-        "--skip_confirm", action="store_true", help="跳过任何确认。默认为False"
-    )
-    parser.add_argument(
-        "--silence",
-        action="store_true",
-        help="是否静默执行,不打印任何信息。默认为False",
-    )
+    parser.add_argument("--debug", action="store_true", help="开启 debug 模式")
+    parser.add_argument("--quick", action="store_true", help="进入 auto-coder.nano 无需初始化系统")
+    # 新增 --agent 参数
+    parser.add_argument("--agent", type=str, help="指定要执行的代理指令")
 
     if input_args:
         _args = parser.parse_args(input_args)
@@ -1141,13 +1056,6 @@ def initialize_system():
                 printer.print_text("退出而不初始化.", style="yellow")
                 exit(1)
 
-        # if not os.path.exists(base_persist_dir):
-        #     os.makedirs(base_persist_dir, exist_ok=True)
-        #     printer.print_text("创建目录：{}".format(base_persist_dir), style="green")
-
-        # if first_time:  # 首次启动,配置项目类型
-        #     project_type = configure_project_type()
-
         printer.print_text("项目初始化完成.", style="green")
 
     _init_project()
@@ -1402,6 +1310,16 @@ def manage_models(models_args, models_data, llm: AutoLLM):
         print_models(models_data)
     if models_args[0] == "/check":
         check_models(models_data, llm)
+    if models_args[0] == "/add":
+        m1, m2, m3, m4 = configure_project_model()
+        printer.print_text("正在更新缓存...", style="yellow")
+        memory["models"][m1] = {"base_url": m3, "api_key": m4, "model": m2}
+        printer.print_text(f"供应商配置已成功完成！后续你可以使用 /models 命令, 查看, 新增和修改所有模型", style="green")
+        printer.print_text(f"正在部署 {m1} 模型...", style="green")
+        llm.setup_sub_client(m1,
+                             memory["models"][m1]["api_key"],
+                             memory["models"][m1]["base_url"],
+                             memory["models"][m1]["model"])
     elif models_args[0] == "/add_model":
         add_model_args = models_args[1:]
         add_model_info = {item.split('=')[0]: item.split('=')[1] for item in add_model_args if item}
@@ -1455,42 +1373,74 @@ def configure_project_model():
             HTML(f"<header>{escape(text)}</header>"), style=style)
 
     default_model = {
-        "1": {"name": "ark-deepseek-r1", "base_url": "https://ark.cn-beijing.volces.com/api/v3",
-              "model_name": "deepseek-r1-0528"},
-        "2": {"name": "ark-deepseek-v3", "base_url": "https://ark.cn-beijing.volces.com/api/v3",
-              "model_name": "deepseek-v3-250324"},
-        "3": {"name": "sili-deepseek-r1", "base_url": "https://api.siliconflow.cn/v1",
-              "model_name": "deepseek-ai/DeepSeek-R1"},
-        "4": {"name": "sili-deepseek-v3", "base_url": "https://api.siliconflow.cn/v1",
-              "model_name": "deepseek-ai/DeepSeek-V3"},
-        "5": {"name": "deepseek-r1", "base_url": "https://api.deepseek.com", "model_name": "deepseek-reasoner"},
-        "6": {"name": "deepseek-v3", "base_url": "https://api.deepseek.com", "model_name": "deepseek-chat"},
+        "1": {"name": "(Volcengine)deepseek/deepseek-r1-0528",
+              "base_url": "https://ark.cn-beijing.volces.com/api/v3",
+              "model_name": "deepseek-r1-250528"},
+        "2": {"name": "(Volcengine)deepseek/deepseek-v3.1-0821",
+              "base_url": "https://ark.cn-beijing.volces.com/api/v3",
+              "model_name": "deepseek-v3-1-250821"},
+        "3": {"name": "(Volcengine)byte/doubao-seed-1.6-250615",
+              "base_url": "https://ark.cn-beijing.volces.com/api/v3",
+              "model_name": "doubao-seed-1-6-250615"},
+        "4": {"name": "(Volcengine)moonshotai/kimi-k2",
+              "base_url": "https://ark.cn-beijing.volces.com/api/v3",
+              "model_name": "kimi-k2-250711"},
+        "5": {"name": "(OpenRouter)google/gemini-2.5-pro",
+              "base_url": "https://openrouter.ai/api/v1",
+              "model_name": "google/gemini-2.5-pro"},
+        "6": {"name": "(OpenRouter)google/gemini-2.5-flash",
+              "base_url": "https://openrouter.ai/api/v1",
+              "model_name": "google/gemini-2.5-flash"},
+        "7": {"name": "(OpenRouter)anthropic/claude-opus-4",
+              "base_url": "https://openrouter.ai/api/v1",
+              "model_name": "anthropic/claude-opus-4"},
+        "8": {"name": "(OpenRouter)anthropic/claude-sonnet-4",
+              "base_url": "https://openrouter.ai/api/v1",
+              "model_name": "anthropic/claude-sonnet-4"},
+        "9": {"name": "(OpenRouter)moonshotai/kimi-k2",
+              "base_url": "https://openrouter.ai/api/v1",
+              "model_name": "moonshotai/kimi-k2"},
+        "10": {"name": "(OpenRouter)openai/gpt-5",
+               "base_url": "https://openrouter.ai/api/v1",
+               "model_name": "openai/gpt-5"},
+        "11": {"name": "(BigModel)bigmodel/glm-4.5",
+               "base_url": "https://open.bigmodel.cn/api/paas/v4",
+               "model_name": "glm-4.5"},
     }
 
+    # 内置模型
     print_header(f"\n=== 正在配置项目模型 ===\n")
-    print_info("选择您的首选模型供应商: ")
-    print_info(f"  1. 火山方舟 DeepSeek-R1")
-    print_info(f"  2. 火山方舟 DeepSeek-V3")
-    print_info(f"  3. 硅基流动 DeepSeek-R1(非Pro)")
-    print_info(f"  4. 硅基流动 DeepSeek-V3(非Pro)")
-    print_info(f"  5. 官方 DeepSeek-R1")
-    print_info(f"  6. 官方 DeepSeek-V3")
-    print_info(f"  7. 其他供应商")
-    model_num = input(f"  请选择您想使用的模型供应商编号(1-6): ").strip().lower()
+    print_info("Volcengine: https://www.volcengine.com/")
+    print_info("OpenRouter: https://openrouter.ai/")
+    print_info("")
+    print_info(f"  1. (Volcengine)deepseek/deepseek-r1-0528")
+    print_info(f"  2. (Volcengine)deepseek/deepseek-v3.1-0821")
+    print_info(f"  3. (Volcengine)byte/doubao-seed-1.6-250615")
+    print_info(f"  4. (Volcengine)moonshotai/kimi-k2")
+    print_info(f"  5. (OpenRouter)google/gemini-2.5-pro")
+    print_info(f"  6. (OpenRouter)google/gemini-2.5-flash")
+    print_info(f"  7. (OpenRouter)anthropic/claude-opus-4")
+    print_info(f"  8. (OpenRouter)anthropic/claude-sonnet-4")
+    print_info(f"  9. (OpenRouter)moonshotai/kimi-k2")
+    print_info(f"  10. (OpenRouter)openai/gpt-5")
+    print_info(f"  11. (BigModel)bigmodel/glm-4.5")
+    print_info(f"  12. 其他模型")
+    model_num = input(f"  请选择您想使用的模型供应商编号(1-11): ").strip().lower()
 
-    if int(model_num) < 1 or int(model_num) > 7:
-        printer.print_text("请选择 1-7", style="red")
+    if int(model_num) < 1 or int(model_num) > 12:
+        printer.print_text("请选择 1-12", style="red")
+        save_memory()
         exit(1)
 
-    if model_num == "7":
+    if model_num == "12":  # 只有选择"其他模型"才需要手动输入所有信息
         current_model = input(f"  设置你的首选模型别名(例如: deepseek-v3/r1, ark-deepseek-v3/r1): ").strip().lower()
         current_model_name = input(f"  请输入你使用模型的 Model Name: ").strip().lower()
         current_base_url = input(f"  请输入你使用模型的 Base URL: ").strip().lower()
-        current_api_key = input(f"  请输入您的API密钥: ").strip().lower()
+        current_api_key = input(f"  请输入您的API密钥: ").strip()
         return current_model, current_model_name, current_base_url, current_api_key
 
     model_name_value = default_model[model_num].get("model_name", "")
-    model_api_key = input(f"请输入您的 API 密钥：").strip().lower()
+    model_api_key = input(f"请输入您的 API 密钥：").strip()
     return (
         default_model[model_num]["name"],
         model_name_value,
@@ -1508,7 +1458,7 @@ def rules(query_args: List[str], llm: AutoLLM):
     /rules /analyze         - 分析当前文件，可选提供查询内容
     /rules /commit <提交ID>  - 分析特定提交，必须提供提交ID和查询内容
     """
-    args = get_final_config(query="", delete_execute_file=True)
+    args = get_final_config(project_root, memory, query="", delete_execute_file=True)
     rules_dir_path = os.path.join(project_root, ".auto-coder", "autocoderrules")
     if query_args[0] == "/list":
         printer.print_table_compact(
@@ -1568,15 +1518,21 @@ def is_old_version():
 
 
 def main():
-    _args, runing_args = parse_args()
+    _args, _raw_args = parse_args()
     _args.source_dir = project_root
     convert_yaml_to_config(_args)
 
-    if not runing_args.quick:
+    if not _raw_args.quick:
         initialize_system()
 
-    load_memory()
-    is_old_version()
+    try:
+        load_memory()
+        load_tokenizer()
+        is_old_version()
+    except Exception as e:
+        print(f"\033[91m发生异常:\033[0m \033[93m{type(e).__name__}\033[0m - {str(e)}")
+        exit(1)
+
     completer.update_current_files(memory["current_files"]["files"])
 
     if len(memory["models"]) == 0:
@@ -1608,6 +1564,18 @@ def main():
     if memory["conf"]["code_model"] not in memory["models"].keys():
         printer.print_text("首选 Code 模型与部署模型不一致, 请使用 /conf code_model:& 设置", style="red")
 
+    if _raw_args and _raw_args.agent:
+        instruction = _raw_args.agent
+        try:
+            auto_command(query=instruction, llm=auto_llm)
+        except Exception as e:
+            print(f"\033[91m发生异常:\033[0m \033[93m{type(e).__name__}\033[0m - {str(e)}")
+            if _raw_args.debug:
+                import traceback
+                traceback.print_exc()
+        finally:
+            return
+
     MODES = {
         "normal": "正常模式",
         "auto_detect": "自然语言模式",
@@ -1696,6 +1664,9 @@ def main():
             elif user_input.startswith("/remove_files"):
                 file_names = user_input[len("/remove_files"):].strip().split(",")
                 remove_files(file_names)
+            elif user_input.startswith("/editor"):
+                editor_files = user_input[len("/editor"):].strip()
+                editor_command(editor_files)
             elif user_input.startswith("/index/build"):
                 index_command(llm=auto_llm)
             elif user_input.startswith("/index/query"):
@@ -1717,7 +1688,6 @@ def main():
             elif user_input.startswith("/conf"):
                 conf = user_input[len("/conf"):].strip()
                 if not conf:
-                    # print(memory["conf"])
                     print_conf(memory["conf"])
                 else:
                     configure(conf)
@@ -1748,7 +1718,15 @@ def main():
                 if not query:
                     print("\033[91mPlease enter your request.\033[0m")
                     continue
-                agentic_command(query=query, llm=auto_llm)
+                auto_command(query=query, llm=auto_llm)
+            elif user_input.startswith("/long_context_auto"):
+                long_context_auto_command(llm=auto_llm)
+            elif user_input.startswith("/context"):
+                context_args = user_input[len("/context"):].strip().split()
+                if not context_args:
+                    print("\033[91mPlease enter your request.\033[0m")
+                    continue
+                context_command(context_args)
             elif user_input.startswith("/chat"):
                 query = user_input[len("/chat"):].strip()
                 if not query:
@@ -1792,7 +1770,7 @@ def main():
             break
         except Exception as e:
             print(f"\033[91m发生异常:\033[0m \033[93m{type(e).__name__}\033[0m - {str(e)}")
-            if runing_args and runing_args.debug:
+            if _raw_args and _raw_args.debug:
                 import traceback
                 traceback.print_exc()
 
