@@ -13,7 +13,7 @@ COMMANDS = {
     "/remove_files": {"/all": ""},
     "/coding": {"/apply": ""},
     "/chat": {"/history": "", "/new": "", "/review": ""},
-    "/models": {"/add_model": "", "/remove": "", "/list": "", "/check": ""},
+    "/models": {"/add_model": "", "/remove": "", "/list": "", "/check": "", "/add": ""},
     "/help": {
         "/add_files": "",
         "/remove_files": "",
@@ -26,7 +26,10 @@ COMMANDS = {
     },
     "/exclude_files": {"/list": "", "/drop": ""},
     "/exclude_dirs": {},
-    "/rules": {"/list": "", "/show": "", "/remove": "", "/analyze": "", "/commit": ""}
+    "/auto": {"/new": "", "/resume": ""},
+    "/editor": {},
+    "/rules": {"/list": "", "/show": "", "/remove": "", "/analyze": "", "/commit": ""},
+    "/context": {"/list": "", "/remove": ""}
 }
 
 
@@ -297,8 +300,8 @@ class CommandCompleter(Completer):
                     if mode.startswith(left_word.strip()):
                         yield Completion(mode, start_position=-len(left_word.strip()))
 
-            if words[0] == "/add_files":
-                new_text = text[len("/add_files"):]
+            if words[0] in ("/add_files", "/editor"):
+                new_text = text[len(words[0]):]
                 parser = CommandTextParser(new_text, words[0])
                 parser.add_files()
                 current_word = parser.current_word()
@@ -337,7 +340,7 @@ class CommandCompleter(Completer):
                             if current_word and current_word in file_name:
                                 yield Completion(file_name, start_position=-len(current_word))
 
-            elif words[0] in ["/chat", "/coding"]:
+            elif words[0] in ["/chat", "/coding", "/auto"]:
                 image_extensions = (
                     ".png", ".jpg", ".jpeg", ".gif", ".bmp", ".tiff", ".tif", ".webp", ".svg", ".ico",
                     ".heic", ".heif", ".raw", ".cr2", ".nef", ".arw", ".dng", ".orf", ".rw2", ".pef",
@@ -550,6 +553,15 @@ class CommandCompleter(Completer):
                     if command.startswith(current_word):
                         yield Completion(command, start_position=-len(current_word))
 
+            elif words[0] == "/context":
+                new_text = text[len("/context"):]
+                parser = CommandTextParser(new_text, words[0])
+                parser.add_files()
+                current_word = parser.current_word()
+                for command in parser.get_sub_commands():
+                    if command.startswith(current_word):
+                        yield Completion(command, start_position=-len(current_word))
+
             elif words[0] == "/conf":
                 new_words = text[len("/conf"):].strip().split()
                 is_at_space = text[-1] == " "
